@@ -5,7 +5,8 @@
 #' @param variable a numeric vector.
 #' @param h integer; 1 (default) Number of periods to forecast.
 #' @param training.set \code{NULL} (defualt) numeric; Sets the number of variable observations \code{(variable[1:training.set])} to monitor performance of forecast over in-sample range.
-#' @param seasonal.factor logical or integer; \code{TRUE} (default) Automatically selects the best seasonal lag from the seasonality test.  To use weighted average of all seasonal lags set to \code{(seasonal.factor=FALSE)}.  Otherwise, directly input known frequency integer lag to use, i.e. \code{(seasonal.factor=12)} for monthly data.
+#' @param seasonal.factor logical or integer(s); \code{TRUE} (default) Automatically selects the best seasonal lag from the seasonality test.  To use weighted average of all seasonal lags set to \code{(seasonal.factor=FALSE)}.  Otherwise, directly input known frequency integer lag to use, i.e. \code{(seasonal.factor=12)} for monthly data.  Multiple frequency integers can also be used, i.e. \code{(seasonal.factor=c(12,24,36))}
+#' @param best.periods integer; to be used in conjuction with \code{(seasonal.factor=FALSE)}, uses the \code{best.periods} number of detected seasonal lags instead of \code{ALL} lags when \code{(seasonal.factor=FALSE)}.
 #' @param negative.values logical; \code{FALSE} (default) If the variable can be negative, set to \code{(negative.values=TRUE)}.
 #' @param method options:("lin","nonlin","both"); \code{"nonlin"} (default)  To select the regression type of the component series, select \code{(method="both")} where both linear and nonlinear estimates are generated.  To use a nonlineaer regression, set to \code{(method="nonlin")}; to use a linear regression set to \code{(method="lin")}.
 #' @param dynamic logical; \code{FALSE} (default) To update the seasonal factor with each forecast point, set to \code{(dynamic=TRUE)}.  The default is \code{(dynamic=FALSE)} to retain the original seasonal factor from the inputted variable for all ensuing \code{h}.
@@ -14,26 +15,44 @@
 #' @param intervals logical; \code{FALSE} (default) Plots the surrounding forecasts around the final estimate when \code{(intervals=TRUE)} and \code{(seasonal.factor=FALSE)}.  There are no other forecasts to plot when a single \code{seasonal.factor} is selected.
 #' @return Returns a vector of forecasts of length \code{(h)}.
 #' @note \code{(seasonal.factor=FALSE)} can be a very comutationally expensive exercise due to the number of seasonal periods detected.
+#'
+#' If error encountered:
+#'
+#' \code{"NaNs produced Error in seq.default(length(variable)+1, 1, -lag[i]) : wrong sign in 'by' argument"}
+#'
+#' when \code{(seasonal.factor=TRUE)}, try the combination of \code{(seasonal.factor=FALSE) and (best.periods=1)} as those two settings are equivalent.
 #' @keywords Autoregressive model
 #' @author Fred Viole, OVVO Financial Systems
 #' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
 #' \url{http://amzn.com/1490523995}
 #' @examples
+#'
 #' ## Nonlinear NNS.ARMA using AirPassengers monthly data and 12 period lag
-#' NNS.ARMA(AirPassengers,h=45,training.set=100,seasonal.factor=12,method='nonlin')
+#' \dontrun{
+#' NNS.ARMA(AirPassengers,h=45,training.set=100,seasonal.factor=12,method='nonlin')}
+#'
+#' ## Nonlinear NNS.ARMA using AirPassengers monthly data and 12, 24, and 36 period lags
+#' \dontrun{
+#' NNS.ARMA(AirPassengers,h=45,training.set=100,seasonal.factor=c(12,24,36),method='nonlin')}
+#'
+#' ## Nonlinear NNS.ARMA using AirPassengers monthly data and 2 best periods lag
+#' \dontrun{
+#' NNS.ARMA(AirPassengers,h=45,training.set=100,seasonal.factor=FALSE,best.periods=2,method='nonlin')}
+#'
 #' @export
 
 
 
 # Autoregressive Model
-NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,negative.values = FALSE, method = "nonlin", dynamic = FALSE,plot=TRUE,seasonal.plot=TRUE,intervals=FALSE){
+NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,best.periods=NULL,negative.values = FALSE, method = "nonlin", dynamic = FALSE,plot=TRUE,seasonal.plot=TRUE,intervals=FALSE){
 
   if(intervals==TRUE && is.numeric(seasonal.factor)){stop('Hmmm...Seems you have "intervals" and "seasonal.factor" selected.  Please set "intervals=F" or "seasonal.factor=F"')}
 
   if(intervals==TRUE && seasonal.factor==TRUE){stop('Hmmm...Seems you have "intervals" and "seasonal.factor" selected.  Please set "intervals=F" or "seasonal.factor=F"')}
 
+  if(is.numeric(seasonal.factor) && dynamic==TRUE){stop('Hmmm...Seems you have "seasonal.factor" specified and "dynamic==TRUE".  Nothing dynamic about static seasonal factors!  Please set "dynamic=F" or "seasonal.factor=F"')}
 
-  variable=as.numeric(variable)
+  variable = as.numeric(variable)
   OV = variable
 
   if(!is.null(training.set)){
@@ -48,7 +67,7 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,n
   Estimates = numeric()
 
   # Weight and lag function for seasonality...
-  ARMA.seas.weighting=function(){
+  ARMA.seas.weighting = function(){
     if(is.null(ncol(M))){
       return(list(lag=M[1],Weights=1))}
 
@@ -62,30 +81,23 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,n
             return(list(lag=lag,Weights=Weights))
         }
 
-      Observation.sum = sum(1/sqrt(M[,1]))
-      Observation.weighting = (1/sqrt(M[,1]))
-
-      Lag.sum = sum(M[,3]-M[,2])
-      Lag.weighting = (M[,3]-M[,2])
-
-
-      Weights = (Lag.weighting*Observation.weighting) / sum(Lag.weighting*Observation.weighting)
-
       # Determine lag from seasonality test
-      if(seasonal.factor==FALSE){lag<- M[,1]}
-      if(is.numeric(seasonal.factor)){
-        lag<- seasonal.factor
-        Weights=1}
-      return(list(lag=lag,Weights=Weights))
-    }}
+      if(seasonal.factor==FALSE){
+        lag = M$Period
+        Observation.weighting = (1/sqrt(lag))
+        Lag.weighting = (M$Variable.Coefficient.of.Variance-M$Coefficient.of.Variance)
+        Weights = (Lag.weighting*Observation.weighting) / sum(Lag.weighting*Observation.weighting)
+        return(list(lag=lag,Weights=Weights))
+    }
 
+}}
   #Vectors generator for 1:lag
   generate.vectors=function(lag){
     Component.series = list()
     Component.index = list()
 
     for (i in 1:length(lag)){
-      CS=rev(variable[seq(aa+1,1,-lag[i])])
+      CS=rev(variable[seq(length(variable)+1,1,-lag[i])])
       CS=CS[!is.na(CS)]
       Component.series[[paste('Series.',i,sep="")]] <- CS
       Component.index[[paste('Index.',i,sep="")]] <- (1:length(CS))
@@ -97,24 +109,15 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,n
 
   if(dynamic == TRUE){
     for (j in 0:(h-1)){
-      if(is.numeric(seasonal.factor)){
-        M<-t(seasonal.factor)
-        lag=seasonal.factor
-        Weights=1
-        seasonal.plot=F
-      } else {
 
         seas.matrix = NNS.seas(variable,plot=F)
         if(!is.list(seas.matrix)){
           M<- t(1)} else {
-            M<- seas.matrix$all.periods}
+            if(is.null(best.periods)){
+            M<- seas.matrix$all.periods} else {M<- seas.matrix$all.periods[1:best.periods,] }}
         ASW=ARMA.seas.weighting()
         lag=ASW$lag
         Weights=ASW$Weights
-      }
-
-      a=length(FV)
-      aa=length(variable)
 
       # Generate vectors for 1:lag
       GV=generate.vectors(lag)
@@ -173,14 +176,22 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,n
     if(is.numeric(seasonal.factor)){
       M<-t(seasonal.factor)
       lag=seasonal.factor
-      Weights=1
+      output=numeric()
+      for(i in 1:length(seasonal.factor)){
+        output[i]<- (abs(sd(variable[seq(length(variable),1,-i)])/mean(variable[seq(length(variable),1,-i)])))
+      }
+      Relative.seasonal= output/(abs(sd(variable)/mean(variable)))
+      Seasonal.weighting = (1/Relative.seasonal)
+      Observation.weighting = (1/sqrt(seasonal.factor))
+      Weights = (Seasonal.weighting) / sum( Seasonal.weighting)
       seasonal.plot=F
     } else {
 
     seas.matrix = NNS.seas(variable,plot=F)
     if(!is.list(seas.matrix)){
       M<- t(1)} else {
-        M<- seas.matrix$all.periods}
+        if(is.null(best.periods)){
+        M<- seas.matrix$all.periods} else {M<- seas.matrix$all.periods[1:best.periods,] }}
     ASW=ARMA.seas.weighting()
     lag=ASW$lag
     Weights=ASW$Weights
@@ -189,9 +200,6 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,n
     Estimate.band= list()
 
     for (j in 0:(h-1)){
-      a=length(FV)
-      aa=length(variable)
-
       # Generate vectors for 1:lag
       GV=generate.vectors(lag)
       Component.index=GV$Component.index
@@ -259,7 +267,7 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,n
       points(M[1,Period],M[1,Coefficient.of.Variance],pch=19,col='red')
 
       abline(h=M[1,Variable.Coefficient.of.Variance], col="red",lty=5)
-      text(median(M[,Period]),M[1,Variable.Coefficient.of.Variance],pos=3,"Variable Coefficient of Variance",col='red')
+      text((M[,min(Period)]+M[,max(Period)])/2,M[1,Variable.Coefficient.of.Variance],pos=3,"Variable Coefficient of Variance",col='red')
     } else {
       par(mfrow=c(2,1))
       plot(1,1,pch=19,col='blue', xlab="Period", ylab="Coefficient of Variance", main = "Seasonality Test",         ylim = c(0,2*abs(sd(FV)/mean(FV))))
@@ -268,6 +276,7 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,n
     }
     }
     label=names(variable)
+    if(is.null(label)){label = "Variable"}
     plot(OV, type = 'l',lwd=2,main = "Forecast",col='steelblue',
           xlim=c(1,max((training.set+h),length(OV))),
           ylab=label, ylim=c(min(Estimates, OV),max( OV,Estimates)))
@@ -304,6 +313,7 @@ NNS.ARMA <- function(variable,h=1,training.set = NULL, seasonal.factor = TRUE ,n
 
     par(mfrow=c(1,1))
   }
+
   return(Estimates)
 
 }
