@@ -1,8 +1,8 @@
 #' NNS FSD Test uni-directional
 #'
 #' Uni-directional test of first degree stochastic dominance using lower partial moments used in SD Efficient Set routine.
-#' @param x variable
-#' @param y variable
+#' @param x a numeric vector.
+#' @param y a numeric vector.
 #' @return Returns (1) if \code{"X FSD Y"}, else (0).
 #' @keywords stochastic dominance
 #' @author Fred Viole, OVVO Financial Systems
@@ -27,29 +27,11 @@ NNS.FSD.uni <- function(x,y){
   output_x <- vector("numeric", length(x))
   output_y <- vector("numeric", length(x))
 
-  if(min(y)>=min(x)) {return(0)} else {
+  if(min(y)>min(x)) {return(0)} else {
 
+    x.fsd.y=sum((LPM(0,Combined_sort,y)-LPM(0,Combined_sort,x))>=0)
 
-  for (i in 1:length(Combined)){
-
-    ## Indicator function ***for all values of x and y*** as the CDF target
-    if(LPM(0,Combined_sort[i],y)-LPM(0,Combined_sort[i],x)>=0 )
-    {output_x[i]<-0} else { break } }
-
-
-  for (i in 1:length(Combined)){
-    if(LPM(0,Combined_sort[i],x)-LPM(0,Combined_sort[i],y)>=0 )
-    {output_y[i]<-0} else { break }
-
-  }
-
-
-  for (j in 1:length(Combined_sort)){
-    LPM_x_sort[j] = LPM(0,Combined_sort[j],x)
-    LPM_y_sort[j] = LPM(0,Combined_sort[j],y)
-  }
-
-  ifelse(length(output_x)==length(Combined) & min(x)>=min(y),return(1),return(0))
+  ifelse(x.fsd.y==length(Combined) & min(x)>=min(y),return(1),return(0))
 
   }
 }
@@ -57,8 +39,8 @@ NNS.FSD.uni <- function(x,y){
 #' NNS SSD Test uni-directional
 #'
 #' Uni-directional test of second degree stochastic dominance using lower partial moments used in SD Efficient Set routine.
-#' @param x variable
-#' @param y variable
+#' @param x a numeric vector.
+#' @param y a numeric vector.
 #' @return Returns (1) if \code{"X SSD Y"}, else (0).
 #' @author Fred Viole, OVVO Financial Systems
 #' @examples
@@ -76,35 +58,11 @@ NNS.SSD.uni <- function(x,y){
   Combined = c(x_sort,y_sort)
   Combined_sort = sort(Combined, decreasing=FALSE)
 
-  LPM_x_sort = numeric(0)
-  LPM_y_sort = numeric(0)
+  if(min(y)>min(x)) {return(0)} else {
 
-  output_x <- vector("numeric", length(x))
-  output_y <- vector("numeric", length(x))
+    x.ssd.y=sum((LPM(1,Combined_sort,y)-LPM(1,Combined_sort,x))>=0)
 
-  if(min(y)>=min(x)) {return(0)} else {
-
-
-    for (i in 1:length(Combined)){
-
-      ## Indicator function ***for all values of x and y*** as the CDF target
-      if(LPM(1,Combined_sort[i],y)-LPM(1,Combined_sort[i],x)>=0 )
-      {output_x[i]<-0} else { break } }
-
-
-    for (i in 1:length(Combined)){
-      if(LPM(1,Combined_sort[i],x)-LPM(1,Combined_sort[i],y)>=0 )
-      {output_y[i]<-0} else { break }
-
-    }
-
-
-    for (j in 1:length(Combined_sort)){
-      LPM_x_sort[j] = LPM(1,Combined_sort[j],x)
-      LPM_y_sort[j] = LPM(1,Combined_sort[j],y)
-    }
-
-    ifelse(length(output_x)==length(Combined) & min(x)>=min(y),return(1),return(0))
+    ifelse(x.ssd.y==length(Combined) & min(x)>=min(y),return(1),return(0))
 
   }
 }
@@ -113,8 +71,8 @@ NNS.SSD.uni <- function(x,y){
 #' NNS TSD Test uni-directional
 #'
 #' Uni-directional test of third degree stochastic dominance using lower partial moments used in SD Efficient Set routine.
-#' @param x variable
-#' @param y variable
+#' @param x a numeric vector.
+#' @param y a numeric vector.
 #' @return Returns (1) if \code{"X TSD Y"}, else (0).
 #' @author Fred Viole, OVVO Financial Systems
 #' @examples
@@ -132,35 +90,11 @@ NNS.TSD.uni <- function(x,y){
   Combined = c(x_sort,y_sort)
   Combined_sort = sort(Combined, decreasing=FALSE)
 
-  LPM_x_sort = numeric(0)
-  LPM_y_sort = numeric(0)
+  if(min(y)>min(x) | mean(y)>mean(x)) {return(0)} else {
 
-  output_x <- vector("numeric", length(x))
-  output_y <- vector("numeric", length(x))
+    x.tsd.y=sum((LPM(2,Combined_sort,y)-LPM(2,Combined_sort,x))>=0)
 
-  if(min(y)>=min(x) | mean(y)>=mean(x)) {return(0)} else {
-
-
-    for (i in 1:length(Combined)){
-
-      ## Indicator function ***for all values of x and y*** as the CDF target
-      if(LPM(2,Combined_sort[i],y)-LPM(2,Combined_sort[i],x)>=0 )
-      {output_x[i]<-0} else { break } }
-
-
-    for (i in 1:length(Combined)){
-      if(LPM(2,Combined_sort[i],x)-LPM(2,Combined_sort[i],y)>=0 )
-      {output_y[i]<-0} else { break }
-
-    }
-
-
-    for (j in 1:length(Combined_sort)){
-      LPM_x_sort[j] = LPM(2,Combined_sort[j],x)
-      LPM_y_sort[j] = LPM(2,Combined_sort[j],y)
-    }
-
-    ifelse(length(output_x)==length(Combined) & min(x)>=min(y),return(1),return(0))
+    ifelse(x.tsd.y==length(Combined) & min(x)>=min(y),return(1),return(0))
 
   }
 }
